/*
** Module   : DynamicResource.java
** Abstract : Defines the DYNAMIC attribute.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 CA  20131021 Created initial version.
*/

package com.goldencode.p2j.util;

/**
 * Interface marking resources which can be dynamic. These APIs can be used to differentiate 
 * between static and dynamic resources; a common property of static resources is that they can
 * not be deleted using the <code>DELETE OBJECT</code> or <code>DELETE WIDGET</code> statement.
 */
public interface DynamicResource
{
   /**
    * Checks  whether the resource is dynamic or static.
    * 
    * @return   <code>true</code> if the resource is dynamic, <code>false</code> otherwise. 
    */
   @LegacyAttribute(name = "DYNAMIC")
   public logical dynamic();

   /**
    * Conversion of DYNAMIC attribute. Returns <code>true</code> if the buffer is dynamic.
    *
    * @return   <code>true</code> if the resource is dynamic, <code>false</code> otherwise. 
    */
   @LegacyAttribute(name = "DYNAMIC")
   public boolean _dynamic();
}
